==> vue-markdown-editor-1.7.13.tgz: package/lib/utils/markdown-it-katex.js <==
"use strict";

// Modified from https://github.com/waylonflinn/markdown-it-katex/blob/master/index.js

/* eslint-disable */
function isValidDelim(state, pos) {
  var prevChar;
  var nextChar;
  var max = state.posMax;
  var can_open = true;
  var can_close = true;
  prevChar = pos > 0 ? state.src.charCodeAt(pos - 1) : -1;
  nextChar = pos + 1 <= max ? state.src.charCodeAt(pos + 1) : -1;
  if (prevChar === 0x20 /* " " */ || prevChar === 0x09 /* \t */ || nextChar >= 0x30 /* "0" */ && nextChar <= 0x39 /* "9" */) {
    can_close = false;
  }
  if (nextChar === 0x20 /* " " */ || nextChar === 0x09 /* \t */) {
    can_open = false;
  }
  return {
    can_open: can_open,
    can_close: can_close
  };
}
function math_inline(state, silent) {
  var start;
  var match;
  var token;
  var res;
  var pos;
  var esc_count;
  if (state.src[state.pos] !== '$') {
    return false;
  }
  res = isValidDelim(state, state.pos);
  if (!res.can_open) {
    if (!silent) {
      state.pending += '$';
    }
    state.pos += 1;
    return true;
  }
  start = state.pos + 1;
  match = start;
  while ((match = state.src.indexOf('$', match)) !== -1) {
    pos = match - 1;
    while (state.src[pos] === '\\') {
      pos -= 1;
    }
    if ((match - pos) % 2 == 1) {
      break;
    }
    match += 1;
  }
  if (match === -1) {
    if (!silent) {
      state.pending += '$';
    }
    state.pos = start;
    return true;
  }
  if (match - start === 0) {
    if (!silent) {
      state.pending += '$$';
    }
    state.pos = start + 1;
    return true;
  }
  res = isValidDelim(state, match);
  if (!res.can_close) {
    if (!silent) {
      state.pending += '$';
    }
    state.pos = start;
    return true;
  }
  if (!silent) {
    token = state.push('math_inline', 'math', 0);
    token.markup = '$';
    token.content = state.src.slice(start, match);
  }
  state.pos = match + 1;
  return true;
}
function math_block(state, start, end, silent) {
  var firstLine;
  var lastLine;
  var next;
  var lastPos;
  var found = false;
  var token;
  var pos = state.bMarks[start] + state.tShift[start];
  var max = state.eMarks[start];
  if (pos + 2 > max) {
    return false;
  }
  if (state.src.slice(pos, pos + 2) !== '$$') {
    return false;
  }
  pos += 2;
  firstLine = state.src.slice(pos, max);
  if (silent) {
    return true;
  }
  if (firstLine.trim().slice(-2) === '$$') {
    firstLine = firstLine.trim().slice(0, -2);
    found = true;
  }
  for (next = start; !found;) {
    next++;
    if (next >= end) {
      break;
    }
    pos = state.bMarks[next] + state.tShift[next];
    max = state.eMarks[next];
    if (pos < max && state.tShift[next] < state.blkIndent) {
      break;
    }
    if (state.src.slice(pos, max).trim().slice(-2) === '$$') {
      lastPos = state.src.slice(0, max).lastIndexOf('$$');
      lastLine = state.src.slice(pos, lastPos);
      found = true;
    }
  }
  state.line = next + 1;
  token = state.push('math_block', 'math', 0);
  token.block = true;
  token.content = (firstLine && firstLine.trim() ? firstLine + '\n' : '') + state.getLines(start + 1, next, state.tShift[start], true) + (lastLine && lastLine.trim() ? lastLine : '');
  token.map = [start, state.line];
  token.markup = '$$';
  return true;
}
module.exports = function math_plugin(md, options) {
  options = options || {};
  var _options = options,
    katex = _options.katex;
  var katexInline = function katexInline(latex) {
    options.displayMode = false;
    try {
      return katex.renderToString(latex, options);
    } catch (error) {
      if (options.throwOnError) {
        console.log(error);
      }
      return latex;
    }
  };
  var inlineRenderer = function inlineRenderer(tokens, idx) {
    return katexInline(tokens[idx].content);
  };
  var katexBlock = function katexBlock(latex) {
    options.displayMode = true;
    try {
      return '<p>' + katex.renderToString(latex, options) + '</p>';
    } catch (error) {
      if (options.throwOnError) {
        console.log(error);
      }
      return latex;
    }
  };
  var blockRenderer = function blockRenderer(tokens, idx) {
    return katexBlock(tokens[idx].content) + '\n';
  };
  md.inline.ruler.after('escape', 'math_inline', math_inline);
  md.block.ruler.after('blockquote', 'math_block', math_block, {
    alt: ['paragraph', 'reference', 'blockquote', 'list']
  });
  md.renderer.rules.math_inline = inlineRenderer;
  md.renderer.rules.math_block = blockRenderer;
};

==> vue-markdown-editor-1.7.14.tgz: package/lib/utils/markdown-it-katex.js <==
"use strict";

// Modified from https://github.com/waylonflinn/markdown-it-katex/blob/master/index.js

function isValidDelim(state, pos) {
  var max = state.posMax;
  var can_open = true;
  var can_close = true;
  var prevChar = pos > 0 ? state.src.charCodeAt(pos - 1) : -1;
  var nextChar = pos + 1 <= max ? state.src.charCodeAt(pos + 1) : -1;
  if (prevChar === 0x20 /* " " */ || prevChar === 0x09 /* \t */ || nextChar >= 0x30 /* "0" */ && nextChar <= 0x39 /* "9" */) {
    can_close = false;
  }
  if (nextChar === 0x20 /* " " */ || nextChar === 0x09 /* \t */) {
    can_open = false;
  }
  return {
    can_open: can_open,
    can_close: can_close
  };
}
function math_inline(state, silent) {
  var match;
  var token;
  var res;
  var pos;
  if (state.src[state.pos] !== '$') {
    return false;
  }
  res = isValidDelim(state, state.pos);
  if (!res.can_open) {
    if (!silent) {
      state.pending += '$';
    }
    state.pos += 1;
    return true;
  }
  var start = state.pos + 1;
  match = start;
  while ((match = state.src.indexOf('$', match)) !== -1) {
    pos = match - 1;
    while (state.src[pos] === '\\') {
      pos -= 1;
    }
    if ((match - pos) % 2 === 1) {
      break;
    }
    match += 1;
  }
  if (match === -1) {
    if (!silent) {
      state.pending += '$';
    }
    state.pos = start;
    return true;
  }
  if (match - start === 0) {
    if (!silent) {
      state.pending += '$$';
    }
    state.pos = start + 1;
    return true;
  }
  res = isValidDelim(state, match);
  if (!res.can_close) {
    if (!silent) {
      state.pending += '$';
    }
    state.pos = start;
    return true;
  }
  if (!silent) {
    token = state.push('math_inline', 'math', 0);
    token.markup = '$';
    token.content = state.src.slice(start, match);
  }
  state.pos = match + 1;
  return true;
}
function math_block(state, start, end, silent) {
  var firstLine;
  var lastLine;
  var next;
  var lastPos;
  var found = false;
  var pos = state.bMarks[start] + state.tShift[start];
  var max = state.eMarks[start];
  if (pos + 2 > max) {
    return false;
  }
  if (state.src.slice(pos, pos + 2) !== '$$') {
    return false;
  }
  pos += 2;
  firstLine = state.src.slice(pos, max);
  if (silent) {
    return true;
  }
  if (firstLine.trim().slice(-2) === '$$') {
    firstLine = firstLine.trim().slice(0, -2);
    found = true;
  }
  for (next = start; !found;) {
    next++;
    if (next >= end) {
      break;
    }
    pos = state.bMarks[next] + state.tShift[next];
    max = state.eMarks[next];
    if (pos < max && state.tShift[next] < state.blkIndent) {
      break;
    }
    if (state.src.slice(pos, max).trim().slice(-2) === '$$') {
      lastPos = state.src.slice(0, max).lastIndexOf('$$');
      lastLine = state.src.slice(pos, lastPos);
      found = true;
    }
  }
  state.line = next + 1;
  var token = state.push('math_block', 'math', 0);
  token.block = true;
  token.content = (firstLine && firstLine.trim() ? firstLine + "\n" : '') + state.getLines(start + 1, next, state.tShift[start], true) + (lastLine && lastLine.trim() ? lastLine : '');
  token.map = [start, state.line];
  token.markup = '$$';
  return true;
}
module.exports = function math_plugin(md, options) {
  options = options || {};
  var _options = options,
    katex = _options.katex;
  var katexInline = function katexInline(latex) {
    options.displayMode = false;
    try {
      return katex.renderToString(latex, options);
    } catch (error) {
      if (options.throwOnError) {
        console.log(error);
      }
      return latex;
    }
  };
  var inlineRenderer = function inlineRenderer(tokens, idx) {
    return katexInline(tokens[idx].content);
  };
  var katexBlock = function katexBlock(latex) {
    options.displayMode = true;
    try {
      return "<p>" + katex.renderToString(latex, options) + "</p>";
    } catch (error) {
      if (options.throwOnError) {
        console.log(error);
      }
      return latex;
    }
  };
  var blockRenderer = function blockRenderer(tokens, idx) {
    return katexBlock(tokens[idx].content) + "\n";
  };
  md.inline.ruler.after('escape', 'math_inline', math_inline);
  md.block.ruler.after('blockquote', 'math_block', math_block, {
    alt: ['paragraph', 'reference', 'blockquote', 'list']
  });
  md.renderer.rules.math_inline = inlineRenderer;
  md.renderer.rules.math_block = blockRenderer;
};
